@@ -1,5 +1,4 @@
-
-import time
+import logging
 from concurrent.futures import ThreadPoolExecutor, as_completed
 from functools import wraps
 from func_timeout import func_timeout
@@ -7,7 +6,8 @@ from func_timeout.exceptions import FunctionTimedOut
 from multiprocessing import Pool
 from queue import Queue
 from threading import Thread, Lock, Timer, Condition
-from typing import Callable, Optional, Union
+from time import time, sleep
+from typing import Callable, Optional, Union, Any
 
 
 class Singleton(type):
@@ -55,13 +55,29 @@ def function_thread(fn: Callable, daemon: bool, *args, **kwargs):
     return Thread(target=fn, args=args, kwargs=kwargs, daemon=daemon)
 
 
+def retry(func: Callable, retry_count: int = 3, sleep_seconds: float = 1.0, *args, **kwargs) -> Any:
+    retry = 0
+    result = None
+    while True:
+        try:
+            result = func(args=args, kwargs=kwargs)
+            break
+        except Exception as e:
+            retry += 1
+            if retry >= retry_count:
+                raise Exception(f'retry failed, error: {str(e)}')
+            logging.warning(f'Failed at attempt: {retry}, error: {str(e)}')
+            sleep(sleep_seconds)
+    return result
+
+
 def set_timeout_wrapper(timeout):
     def inner_set_timeout_wrapper(func):
         @wraps(func)
         def wrapper(*args, **kwargs):
             try:
                 return func_timeout(timeout, func, args=args, kwargs=kwargs)
-            except FunctionTimedOut as e:
+            except FunctionTimedOut:
                 raise Exception(f'func({func.__name__}) time out')
             except Exception as e:
                 raise e
@@ -71,11 +87,11 @@ def set_timeout_wrapper(timeout):
 
 class RepeatingTimer(Timer):
 
-    '''
+    """
      @daemon_thread
         def thread_func():
             pass
-    '''
+    """
 
     def run(self):
         self.finished.wait(self.interval)
@@ -84,7 +100,7 @@ class RepeatingTimer(Timer):
             self.finished.wait(self.interval)
 
 
-class SimpleTimer():
+class SimpleTimer:
 
     def __init__(self):
         self.timer = None
@@ -116,7 +132,7 @@ class RepeatThreadPool:
         self.kwargs = kwargs
         self.pool_size = size              # 线程池大小
         self.pool_fun = fun                # 线程函数
-        self.pools = ThreadPoolExecutor(self.pool_size) # 线程池
+        self.pools = ThreadPoolExecutor(self.pool_size)  # 线程池
         self.done_callback = done_callback              # 线程执行回调函数
 
         self.task_queue = Queue()               # 待处理队列
@@ -135,14 +151,14 @@ class RepeatThreadPool:
             if isinstance(task_index, int) and task_index > 0:
                 task_info = self.task_cache.get(task_index)
                 if isinstance(task_info, dict):
-                    task_info['process'] = time.time()
+                    task_info['process'] = time()
                     future = self.pools.submit(task_info.get('task'), *(task_info.get('args')))
                     self.task_running[future] = task_index
                     future.add_done_callback(self.future_callback)
 
     def add_task(self, task, task_back, *args, **kwargs) -> int:
         index = len(self.task_cache) + 1
-        self.task_cache[index] = {'index': index, 'create': time.time(), 'task': task, 'task_back': task_back, 'args': args, 'kwargs': kwargs}
+        self.task_cache[index] = {'index': index, 'create': time(), 'task': task, 'task_back': task_back, 'args': args, 'kwargs': kwargs}
         self.task_queue.put(index)
         return index
 
@@ -169,7 +185,7 @@ class RepeatThreadPool:
             if isinstance(task_info, dict):
                 task_info['future'] = future
                 task_info['result'] = future.result()
-                task_info['end'] = time.time()
+                task_info['end'] = time()
                 task_info['cost'] = '{:.3f}'.format(task_info['end'] - task_info['process'])
                 done_callback = task_info.get('task_back')
                 if done_callback:
@@ -183,7 +199,7 @@ class RepeatThreadPool:
 
     def done(self):
         while self.finish() is False:
-            time.sleep(1)
+            sleep(1)
 
     def status(self):
         return self.pool_status
@@ -198,7 +214,7 @@ class SimpleThreadPool:
         self.kwargs = kwargs
         self.pool_size = size              # 线程池大小
         self.pool_fun = fun                # 线程函数
-        self.pools = ThreadPoolExecutor(self.pool_size) # 线程池
+        self.pools = ThreadPoolExecutor(self.pool_size)  # 线程池
         self.done_callback = done_callback              # 线程执行回调函数
         self.task_future = []
 
@@ -231,7 +247,7 @@ class ThreadPool:
         self.pool_cost = 0
 
     def run(self, dict_result: bool = True):
-        start = time.time()
+        start = time()
         with ThreadPoolExecutor(self.pool_size) as executor:
             futures = [executor.submit(self.pool_fun, *fun_param) for fun_param in self.fun_params]
 
@@ -247,7 +263,7 @@ class ThreadPool:
                 else:
                     results_list.append(result)
 
-        self.pool_cost = '{:.3f}'.format(time.time() - start)
+        self.pool_cost = '{:.3f}'.format(time() - start)
         return results_dict if dict_result else results_list
 
     def cost(self):
@@ -263,7 +279,7 @@ class MultiPool:
         self.pool_cost = 0
 
     def run(self, dict_result: bool = True):
-        start = time.time()
+        start = time()
         results_dict = {}
         results_list = []
         with Pool(self.pool_size) as p:
@@ -278,7 +294,7 @@ class MultiPool:
                     else:
                         results_list.append(result)
 
-        self.pool_cost = '{:.3f}'.format(time.time() - start)
+        self.pool_cost = '{:.3f}'.format(time() - start)
         return results_dict if dict_result else results_list
 
     def cost(self):
@@ -304,8 +320,8 @@ class WaitQueue:
                 self.values.append(value)
             self.condition.notify_all()
 
-    def notify(self, value=None, n: int=1):
+    def notify(self, value=None, n: int = 1):
         with self.condition:
             if value is not None:
                 self.values.append(value)
-            self.condition.notify(n)
\ No newline at end of file
+            self.condition.notify(n)
