@@ -326,3 +326,87 @@ def int_to_bytes(data: int, byteorder: str = 'little', signed: bool = False, mod
             return format(data, "x").rjust(8, "0").upper().encode()
         else:
             raise ValueError(f"invalid mode({mode})")
+
+
+#
+def get_bool(value: int, pos: int):
+    if (1 << pos) & value == 0:
+        return 0
+    else:
+        return 1
+
+
+def set_bool(old_value: int, pos: int, bit_value: int):
+    current_bit = get_bool(old_value, pos)
+    if current_bit != bit_value:
+        if bit_value == 1:
+            old_value = old_value + (1 << pos)
+        else:
+            old_value = old_value - (1 << pos)
+    return old_value
+
+
+def unpack_bytes(value: bytes, type_fmt: str):
+    return unpack(type_fmt, value)[0]
+
+
+def pack_value(value, type_fmt: str):
+    return pack(type_fmt, value)
+
+
+# BCD
+def bcd_to_float(value: bytes, precision: int = 0):
+    v = ''
+    for i in range(len(value)):
+        v = f"{v}{(value[len(value) - i - 1]) >> 4 & 0xF}{(value[len(value) - i - 1]) & 0xF}"
+        if len(value) - i - 1 == precision and precision > 0:
+            v = f"{v}."
+    return str(float(v))
+
+
+def accumulate_sum(value: bytes):
+    return sum(value) & 0xFF
+
+
+# Align
+def algin_content(content: str, algin: str, size: int, fill_char: Optional[str] = None) -> str:
+    algins = {'left': '<', 'right': '>', 'center': '^'}
+    _format = f"{{:{'' if fill_char is None else fill_char}{algins.get(algin, '<')}{size}}}"
+    return _format.format(content)
+
+
+# Decimal conversion
+def value_to_decimal(value: Any, type: Optional[str] = None):
+    if type is None:
+        if isinstance(value, bytes):
+            value = value.decode()
+        type = str(value)[0:2]
+
+    type = type.lower()
+    if type == '0b':    # 2进制数（字符串）转10进制数
+        return int(value, 2)
+    elif type == '0o':  # 8进制数
+        return int(value, 8)
+    elif type == '0x':  # 16进制数
+        return int(value, 16)
+    else:
+        return int(value)
+
+
+def value_to_bin(value: Any, type: Optional[str] = None):
+    return bin(value_to_decimal(value, type))   # 转2进制
+
+
+def value_to_oct(value: Any, type: Optional[str] = None):
+    return oct(value_to_decimal(value, type))   # 转8进制
+
+
+def value_to_hex(value: Any, type: Optional[str] = None):
+    return hex(value_to_decimal(value, type))   # 转16进制
+
+
+def try_convert_value(value: Union[str, float, None]) -> Union[str, float, None]:
+    try:
+        return float(value)
+    except (ValueError, TypeError):
+        return value
