@@ -1,18 +1,95 @@
 import pytz
 import logging
 from datetime import datetime, timedelta, tzinfo
-from tzlocal import get_localzone
+from enum import Enum, unique
 from typing import Union, NamedTuple, Tuple, Optional, Any
 from dateutil.relativedelta import relativedelta
 from dateutil.parser import parse
 from ..error.utils import InputDataError
+from ..validation import input
+from ..base.constant import DATETIME_FMT_FULL, DATETIME_FMT_DATE
 
-DATETIME_FMT_FULL = "%Y-%m-%d %H:%M:%S"
-DATETIME_FMT_DATE = "%Y-%m-%d"
-DATETIME_FMT_TIME = "%H:%M:%S"
-# many systems (e.g. Mongo) does not support default datetime.min (0001-01-01 00:00:00),
-# so we have to use a conservative value as minimal datetime.
-DATETIME_SAFE_MIN = datetime(1900, 1, 1)
+
+@unique
+class TimeInterval(Enum):
+    """
+    We do not follow common naming convention for the sake of IOT tradition.
+    """
+    s1 = 's1'
+    m1 = 'm1'
+    m5 = 'm5'
+    h1 = 'h1'
+    d1 = 'd1'
+    M1 = 'M1'
+    TIME_INTERVAL_RANKS = dict(s1=10, m1=20, m5=30, h1=40, d1=50, M1=60)
+
+    def __gt__(self, other):
+        other = input.assert_not_none_enum('other', other, TimeInterval)
+        this_rank = self.TIME_INTERVAL_RANKS[self.value]
+        that_rank = self.TIME_INTERVAL_RANKS[other.value]
+        return this_rank > that_rank
+
+    def __ge__(self, other):
+        other = input.assert_not_none_enum('other', other, TimeInterval)
+        this_rank = self.TIME_INTERVAL_RANKS[self.value]
+        that_rank = self.TIME_INTERVAL_RANKS[other.value]
+        return this_rank >= that_rank
+
+    @property
+    def delta(self):
+        if self == self.s1:
+            return relativedelta(seconds=1)
+        if self == self.m1:
+            return relativedelta(minutes=1)
+        if self == self.m5:
+            return relativedelta(minutes=5)
+        if self == self.h1:
+            return relativedelta(hours=1)
+        if self == self.d1:
+            return relativedelta(days=1)
+        if self == self.M1:
+            return relativedelta(months=1)
+        raise NotImplementedError()
+
+    @property
+    def timedelta(self):
+        if self == self.s1:
+            return timedelta(seconds=1)
+        if self == self.m1:
+            return timedelta(minutes=1)
+        if self == self.m5:
+            return timedelta(minutes=5)
+        if self == self.h1:
+            return timedelta(hours=1)
+        if self == self.d1:
+            return timedelta(days=1)
+        if self == self.M1:
+            return timedelta(days=30)
+        raise NotImplementedError()
+
+    @property
+    def pandas_freq(self):
+        result: str = ''
+        if self == self.s1:
+            result = '1S'
+        elif self == self.m1:
+            result = '1T'
+        elif self == self.m5:
+            result = '5T'
+        elif self == self.h1:
+            result = '1H'
+        elif self == self.d1:
+            result = '1D'
+        elif self == self.M1:
+            result = '1MS'
+        else:
+            raise NotImplementedError()
+        return result
+
+class DateRange(NamedTuple):
+    start_time: datetime
+    end_time: datetime
+    interval: TimeInterval
 
 
 class TimeWindow(NamedTuple):
@@ -91,23 +168,23 @@ def parse_time(s: str):
     return parse(s)
 
 
-def get_datetime(time_zone: Optional[str]=None) -> datetime:
+def get_datetime(time_zone: Optional[str] = None) -> datetime:
     return datetime.now() if time_zone is None or len(time_zone) == '' else datetime.now(pytz.timezone(time_zone))
 
 
-def get_datetime_str(time_zone: Optional[str]=None) -> str:
+def get_datetime_str(time_zone: Optional[str] = None) -> str:
     return datetime.now().strftime(DATETIME_FMT_FULL) if time_zone is None or len(time_zone) == '' else datetime.now(pytz.timezone(time_zone)).strftime(DATETIME_FMT_FULL)
 
 
-def get_date(time_zone: Optional[str]=None) -> str:
+def get_date(time_zone: Optional[str] = None) -> str:
     return get_datetime(time_zone).strftime(DATETIME_FMT_DATE)
 
 
-def get_datetime_stamp(time_zone: Optional[str]=None) -> float:
+def get_datetime_stamp(time_zone: Optional[str] = None) -> float:
     return get_datetime(time_zone).timestamp()
 
 
-def get_datetime_from_stamp(timestamp, time_zone: Optional[str]=None):
+def get_datetime_from_stamp(timestamp, time_zone: Optional[str] = None):
     return datetime.fromtimestamp(timestamp) if time_zone is None else datetime.fromtimestamp(timestamp, pytz.timezone(time_zone))
 
 
@@ -147,9 +224,7 @@ def convert_time_with_timezone(time: datetime, target_tz: str):
     return time.replace(tzinfo=target_tz)
 
 
-def convert_time_by_timezone(original_time: datetime,
-                           original_tz: Union[str, tzinfo],
-                           target_tz: Union[str, tzinfo]) -> datetime:
+def convert_time_by_timezone(original_time: datetime, original_tz: Union[str, tzinfo], target_tz: Union[str, tzinfo]) -> datetime:
     if not isinstance(original_time, datetime):
         raise InputDataError(f"orignial_time must be datetime object!")
     if not original_tz:
@@ -178,6 +253,7 @@ def convert_stamp(stamp: int, original_tz: Union[str, tzinfo], target_tz: Union[
 
     return convert_time_by_timezone(get_datetime_from_stamp(stamp), original_tz, target_tz)
 
+
 def convert_time(time: Union[int, str, datetime], original_tz: Union[str, tzinfo, None], target_tz: Union[str, tzinfo, None], with_zone: bool = False) -> datetime:
     if isinstance(time, str):
         time = parse_time(time)
