@@ -1,11 +1,11 @@
 import logging
-import inspect
-import re
 import sys
 import time
-import traceback
 from colorama import init
+from inspect import stack
+from re import search
 from typing import Any
+from traceback import StackSummary, walk_stack
 from logging.handlers import TimedRotatingFileHandler
 
 from ..os.path import create_dir_if_not_exist
@@ -27,7 +27,7 @@ class MyLoggerHandler(logging.Handler):
             self.handleError(record)
 
 
-class MyLogLevel():
+class MyLogLevel:
     CRITICAL = 50
     FATAL = CRITICAL
     ERROR = 40
@@ -43,8 +43,8 @@ class MyLogRecord(object):
     def __init__(self, msg, log_level: int = MyLogLevel.INFO, fmt: str = LOG_FORMAT, log_time_fmt: str = LOG_TIME_FORMAT, **kwargs):
 
         self.fmt = fmt
-        stack = inspect.stack()[1]
-        self.record = {'level': log_level, 'levelname': '{0:<5s}'.format(logging.getLevelName(log_level))[:5], 'asctime': time.strftime(log_time_fmt, time.localtime(time.time())), 'message': msg, 'filename': get_file_name(stack[1]), 'funcName': stack[3], 'lineno': stack[2]}
+        _stack = stack()[1]
+        self.record = {'level': log_level, 'levelname': '{0:<5s}'.format(logging.getLevelName(log_level))[:5], 'asctime': time.strftime(log_time_fmt, time.localtime(time.time())), 'message': msg, 'filename': get_file_name(_stack[1]), 'funcName': _stack[3], 'lineno': _stack[2]}
 
     def format_msg(self):
         return f"{self.fmt % self.record}"
@@ -53,7 +53,7 @@ class MyLogRecord(object):
         return str(self.record.get('message'))
 
 
-class MyStdout():
+class MyStdout:
 
     def __init__(self, autoreset: bool = True):
         init(autoreset=autoreset)
@@ -64,13 +64,15 @@ class MyStdout():
 
     def write(self, info):
         if info.find('[INFO ]') >= 0:
-            info = f"\033[1;34m{info}\033[0m"
+            info = f"\033[1;30m{info}\033[0m"
         elif info.find('DEBUG') >= 0:
-            info = f"\033[1;36m{info}\033[0m"
+            info = f"\033[1;34m{info}\033[0m"
         elif info.find('[WARNI]') >= 0:
             info = f"\033[1;33m{info}\033[0m"
         elif info.find('[ERROR]') >= 0:
             info = f"\033[1;31m{info}\033[0m"
+        else:
+            info = f"\033[1;30m{info}\033[0m"
         self.stdout_bak.write(info)
 
     def flush(self):
@@ -90,11 +92,11 @@ def init_log(file_path: str, log_level: int, log_interval: int = 1, log_backup:
 
 def convert_msg(log_content: str):
     if len(log_content) > 0:
-        return re.search(r'\[(?P<asctime>.*?)] level: \[(?P<level>.*?)] module: \[(?P<module>.*?)] func: \[(?P<func>.*?)] lineno: \[(?P<lineno>.*?)] msg: \[(?P<msg>.*)]', log_content).groupdict()
+        return search(r'\[(?P<asctime>.*?)] level: \[(?P<level>.*?)] module: \[(?P<module>.*?)] func: \[(?P<func>.*?)] lineno: \[(?P<lineno>.*?)] msg: \[(?P<msg>.*)]', log_content).groupdict()
 
 
 def format_log(log_content: Any):
-    func = inspect.stack()[1]
+    func = stack()[1]
     return {'file': get_file_name(func[1]), 'func': func[3], 'lineno': func[2], 'msg': log_content}
 
 
@@ -108,7 +110,7 @@ def _get_normalized_locals_text(locals_dict) -> str:
 
 
 def log_unhandled_error(**kwargs):
-    stacks = traceback.StackSummary.extract(traceback.walk_stack(None), limit=kwargs.get('limit', 2), capture_locals=kwargs.get('capture_locals', True))
+    stacks = StackSummary.extract(walk_stack(None), limit=kwargs.get('limit', 2), capture_locals=kwargs.get('capture_locals', True))
     stack_len = len(stacks)
     if stack_len == 0:
         locals_text = "NO_STACK"
@@ -116,4 +118,4 @@ def log_unhandled_error(**kwargs):
         locals_text = _get_normalized_locals_text(stacks[0].locals)
     else:
         locals_text = _get_normalized_locals_text(stacks[1].locals)
-    logging.error(f"Unhandled exception! Locals: {locals_text}.", exc_info=kwargs.get('exc_info', False), stack_info=kwargs.get('stack_info', False))
\ No newline at end of file
+    logging.error(f"Unhandled exception! Locals: {locals_text}.", exc_info=kwargs.get('exc_info', False), stack_info=kwargs.get('stack_info', False))
