@@ -30,6 +30,13 @@ def test_parse_time():
 
 
 def test_timestamp():
+    t = get_datetime('Etc/GMT+7')
+    tt = parse_time('2022-06-06T12:15:00-07:00')
+
+    now = datetime(2022, 6, 7, 9, 45)
+    t1 = convert_time(now, 'Asia/Shanghai', 'Etc/GMT+7').replace(second=0)
+    t2 = convert_time(t1, None, 'Etc/GMT+7').replace(second=0)
+    t3 = datetime.now().astimezone(tz=pytz.timezone('Etc/GMT+7')).replace(second=0, microsecond=0)
     tm = 1653039214
     data_time = convert_time(tm, get_timezone(str('UTC'))[0], 'Asia/Shanghai').replace(second=0).strftime("%Y-%m-%d %H:%M:%S")
 
